@@ -822,10 +822,10 @@ struct samplv1_glide
 		m_frames = frames;
 
 		if (m_frames > 0) {
-			m_freq = m_last - freq;
-			m_step = m_freq / float(m_frames);
+			m_freq = m_last;
+			m_step = (m_last - freq) / float(m_frames);
 		} else {
-			m_freq = 0.0f;
+			m_freq = freq;
 			m_step = 0.0f;
 		}
 
@@ -838,6 +838,7 @@ struct samplv1_glide
 			m_freq -= m_step;
 			--m_frames;
 		}
+
 		return m_freq;
 	}
 
@@ -845,8 +846,8 @@ private:
 
 	uint32_t m_frames;
 
-	float m_freq;
-	float m_step;
+	float  m_step;
+	float  m_freq;
 
 	float& m_last;
 };
@@ -1129,6 +1130,7 @@ protected:
 	void allControllersOff();
 	void allNotesOff();
 	void allSustainOff();
+	void allSustainOn();
 
 	float get_bpm ( float bpm ) const
 		{ return (bpm > 0.0f ? bpm : m_bpm); }
@@ -1236,6 +1238,8 @@ samplv1_voice::samplv1_voice ( samplv1_impl *pImpl ) :
 	dcf17(&pImpl->dcf1_formant),
 	dcf18(&pImpl->dcf1_formant),
 	gen1_glide(pImpl->gen1_last),
+	out1_volume(1.0f),
+	out1_panning(0.0f),
 	sustain(false)
 {
 }
@@ -1789,7 +1793,7 @@ void samplv1_impl::process_midi ( uint8_t *data, uint32_t size )
 				pv->out1_panning = 0.0f;
 				pv->out1_pan.reset(&pv->out1_panning);
 				// volume
-				pv->out1_volume = 0.0f;
+				pv->out1_volume = 1.0f;
 				pv->out1_vol.reset(&pv->out1_volume);
 				// sustain
 				pv->sustain = false;
@@ -1807,25 +1811,27 @@ void samplv1_impl::process_midi ( uint8_t *data, uint32_t size )
 				if (m_ctl1.sustain)
 					pv->sustain = true;
 				else
-				if (pv->dca1_env.stage != samplv1_env::Release) {
-					m_dca1.env.note_off(&pv->dca1_env);
-					m_dcf1.env.note_off(&pv->dcf1_env);
-					m_lfo1.env.note_off(&pv->lfo1_env);
-				//	pv->gen1.setLoop(false);
-				}
-				m_notes[pv->note] = nullptr;
-				pv->note = -1;
-				// mono legato?
-				if (*m_def.mono > 0.0f) {
-					do pv = pv->prev();	while (pv && pv->note < 0);
-					if (pv && pv->note >= 0) {
-						const bool legato = (*m_def.mono > 1.0f);
-						m_dcf1.env.restart(&pv->dcf1_env, legato);
-						m_lfo1.env.restart(&pv->lfo1_env, legato);
-						m_dca1.env.restart(&pv->dca1_env, legato);
-						pv->gen1.setLoop(*m_gen1.loop > 0.0f);
-						if (!legato) pv->gen1.start(pv->gen1_freq);
-						m_notes[pv->note] = pv;
+				if (!pv->sustain) {
+					if (pv->dca1_env.stage != samplv1_env::Release) {
+						m_dca1.env.note_off(&pv->dca1_env);
+						m_dcf1.env.note_off(&pv->dcf1_env);
+						m_lfo1.env.note_off(&pv->lfo1_env);
+					//	pv->gen1.setLoop(false);
+					}
+					m_notes[pv->note] = nullptr;
+					pv->note = -1;
+					// mono legato?
+					if (*m_def.mono > 0.0f) {
+						do pv = pv->prev();	while (pv && pv->note < 0);
+						if (pv && pv->note >= 0) {
+							const bool legato = (*m_def.mono > 1.0f);
+							m_dcf1.env.restart(&pv->dcf1_env, legato);
+							m_lfo1.env.restart(&pv->lfo1_env, legato);
+							m_dca1.env.restart(&pv->dca1_env, legato);
+							pv->gen1.setLoop(*m_gen1.loop > 0.0f);
+							if (!legato) pv->gen1.start(pv->gen1_freq);
+							m_notes[pv->note] = pv;
+						}
 					}
 				}
 			}
@@ -1868,6 +1874,13 @@ void samplv1_impl::process_midi ( uint8_t *data, uint32_t size )
 					allSustainOff();
 				m_ctl1.sustain = bool(value >= 64);
 				break;
+			case 0x42:
+				// sustenuto pedal (cc#66)
+				if (value < 64)
+					allSustainOff();
+				else
+					allSustainOn();
+				break;
 			case 0x78:
 				// all sound off (cc#120)
 				allSoundOff();
@@ -1971,6 +1984,19 @@ void samplv1_impl::allSustainOff (void)
 }
 
 
+// sustain all notes on (sustenuto)
+
+void samplv1_impl::allSustainOn (void)
+{
+	samplv1_voice *pv = m_play_list.next();
+	while (pv) {
+		if (pv->note >= 0 && !pv->sustain)
+			pv->sustain = true;
+		pv = pv->next();
+	}
+}
+
+
 // direct note-on triggered on next cycle...
 void samplv1_impl::directNoteOn ( int note, int vel )
 {
