@@ -204,7 +204,7 @@ samplv1_lv2::samplv1_lv2 (
 			host_options = (const LV2_Options_Option *) host_feature->data;
 	}
 
-	uint32_t buffer_size = 0; // whatever happened to safe default?
+	uint32_t buffer_size = 512; // maybe some safe default?
 
 	for (int i = 0; host_options && host_options[i].key; ++i) {
 		const LV2_Options_Option *host_option = &host_options[i];
@@ -550,7 +550,11 @@ void samplv1_lv2::qapp_instantiate (void)
 	if (qApp == nullptr && g_qapp_instance == nullptr) {
 		static int s_argc = 1;
 		static const char *s_argv[] = { SAMPLV1_TITLE, nullptr };
+#if defined(WIN32) || defined(_WIN32) || defined(__WIN32)
+		::_putenv_s("QT_NO_GLIB", "1"); // Avoid glib event-loop...
+#else
 		::setenv("QT_NO_GLIB", "1", 1); // Avoid glib event-loop...
+#endif
 		g_qapp_instance = new QApplication(s_argc, (char **) s_argv);
 	}
 
