@@ -22,7 +22,9 @@
 #include "samplv1widget_filt.h"
 
 #include <QPainter>
-#include <QPainterPath>
+
+#include <QLinearGradient>
+
 #include <QMouseEvent>
 #include <QWheelEvent>
 
@@ -42,7 +44,7 @@ inline float safe_value ( float x )
 // Constructor.
 samplv1widget_filt::samplv1widget_filt ( QWidget *pParent )
 	: QFrame(pParent),
-		m_fCutoff(0.0f), m_fReso(0.0f), m_fType(0.0f), m_fSlope(0.0f),
+		m_fCutoff(0.0f), m_fReso(0.0f), m_iType(LPF), m_iSlope(S12DB),
 		m_bDragging(false)
 {
 //	setMouseTracking(true);
@@ -64,7 +66,7 @@ void samplv1widget_filt::setCutoff ( float fCutoff )
 {
 	if (::fabsf(m_fCutoff - fCutoff) > 0.001f) {
 		m_fCutoff = safe_value(fCutoff);
-		update();
+		updatePath();
 		emit cutoffChanged(cutoff());
 	}
 }
@@ -79,7 +81,7 @@ void samplv1widget_filt::setReso ( float fReso )
 {
 	if (::fabsf(m_fReso - fReso) > 0.001f) {
 		m_fReso = safe_value(fReso);
-		update();
+		updatePath();
 		emit resoChanged(reso());
 	}
 }
@@ -92,29 +94,31 @@ float samplv1widget_filt::reso (void) const
 
 void samplv1widget_filt::setType ( float fType )
 {
-	if (::fabsf(m_fType - fType) > 0.001f) {
-		m_fType = fType;
-		update();
+	const int iType = int(fType);
+	if (m_iType != iType) {
+		m_iType  = iType;
+		updatePath();
 	}
 }
 
 float samplv1widget_filt::type (void) const
 {
-	return m_fType;
+	return float(m_iType);
 }
 
 
 void samplv1widget_filt::setSlope ( float fSlope )
 {
-	if (::fabsf(m_fSlope - fSlope) > 0.001f) {
-		m_fSlope = fSlope;
-		update();
+	const int iSlope = int(fSlope);
+	if (m_iSlope != iSlope) {
+		m_iSlope  = iSlope;
+		updatePath();
 	}
 }
 
 float samplv1widget_filt::slope (void) const
 {
-	return m_fSlope;
+	return float(m_iSlope);
 }
 
 
@@ -124,123 +128,31 @@ void samplv1widget_filt::paintEvent ( QPaintEvent *pPaintEvent )
 	QPainter painter(this);
 
 	const QRect& rect = QWidget::rect();
-	const int h  = rect.height();
-	const int w  = rect.width();
-
-	const int h2 = h >> 1;
-	const int h4 = h >> 2;
-	const int w4 = w >> 2;
-	const int w8 = w >> 3;
-
-	const int iSlope = int(m_fSlope);
-	const int ws = w8 - (iSlope == 1 ? (w8 >> 1) : 0);
-
-	int x = w8 + int(m_fCutoff * float(w - w4));
-	int y = h2 - int(m_fReso   * float(h + h4));
-
-	QPolygon poly(6);
-	QPainterPath path;
-
-	const int iType = (iSlope == 3 ? 4 : int(m_fType));
-	// Low, Notch
-	if (iType == 0 || iType == 3) {
-		if (iType == 3) x -= w8;
-		poly.putPoints(0, 6,
-			0, h2,
-			x - w8, h2,
-			x, h2,
-			x, y,
-			x + ws, h,
-			0, h);
-		path.moveTo(poly.at(0));
-		path.lineTo(poly.at(1));
-		path.cubicTo(poly.at(2), poly.at(3), poly.at(4));
-		path.lineTo(poly.at(5));
-		if (iType == 3) x += w8;
-	}
-	// Band
-	if (iType == 1) {
-		const int y2 = (y + h4) >> 1;
-		poly.putPoints(0, 6,
-			0, h,
-			x - w8 - ws, h,
-			x - ws, y2,
-			x + ws, y2,
-			x + w8 + ws, h,
-			0, h);
-		path.moveTo(poly.at(0));
-		path.lineTo(poly.at(1));
-		path.cubicTo(poly.at(2), poly.at(3), poly.at(4));
-		path.lineTo(poly.at(5));
-	}
-	// High, Notch
-	if (iType == 2 || iType == 3) {
-		if (iType == 3) { x += w8; y = h2; }
-		poly.putPoints(0, 6,
-			x - ws, h,
-			x, y,
-			x, h2,
-			x + w8, h2,
-			w, h2,
-			w, h);
-		path.moveTo(poly.at(0));
-		path.cubicTo(poly.at(1), poly.at(2), poly.at(3));
-		path.lineTo(poly.at(4));
-		path.lineTo(poly.at(5));
-		if (iType == 3) x -= w8;
-	}
-	// Formant
-	if (iType == 4) {
-		const int x2 = (x - w4) >> 2;
-		const int y2 = (y - h4) >> 2;
-		poly.putPoints(0, 6,
-			0, h2,
-			x2, h2,
-			x - ws, h2,
-			x, y2,
-			x + ws, h,
-			0, h);
-		path.moveTo(poly.at(0));
-	#if 0
-		path.lineTo(poly.at(1));
-		path.cubicTo(poly.at(2), poly.at(3), poly.at(4));
-	#else
-		const int n3 = 5; // num.formants
-		const int w3 = (x + ws - x2) / n3 - 1;
-		const int w6 = (w3 >> 1);
-		const int h3 = (h4 >> 1);
-		int x3 = x2; int y3 = y2;
-		for (int i = 0; i < n3; ++i) {
-			poly.putPoints(1, 3,
-				x3, h2,
-				x3 + w6, y3,
-				x3 + w3, y3 + h2);
-			path.cubicTo(poly.at(1), poly.at(2), poly.at(3));
-			x3 += w3; y3 += h3;
-		}
-		path.lineTo(poly.at(4));
-	#endif
-		path.lineTo(poly.at(5));
-	}
+	const int h = rect.height();
+	const int w = rect.width();
 
 	const QPalette& pal = palette();
 	const bool bDark = (pal.window().color().value() < 0x7f);
-	const QColor& rgbLite = (isEnabled()
-		? (bDark ? Qt::darkYellow : Qt::yellow) : pal.mid().color());
-	const QColor& rgbDark = pal.window().color().darker(180);
+	const QColor& rgbLite = (isEnabled() ? Qt::yellow : pal.mid().color());
+	const QColor& rgbDark = pal.window().color().darker();
 
 	painter.fillRect(rect, rgbDark);
 
-	painter.setPen(bDark ? Qt::gray : Qt::darkGray);
+	QColor rgbLite1(rgbLite);
+	QColor rgbDrop1(Qt::black);
+	rgbLite1.setAlpha(bDark ? 80 : 120);
+	rgbDrop1.setAlpha(80);
 
 	QLinearGradient grad(0, 0, w << 1, h << 1);
-	grad.setColorAt(0.0f, rgbLite);
-	grad.setColorAt(1.0f, Qt::black);
+	grad.setColorAt(0.0f, rgbLite1);
+	grad.setColorAt(1.0f, rgbDrop1);
 
 	painter.setRenderHint(QPainter::Antialiasing, true);
 
+//	painter.setPen(bDark ? Qt::gray : Qt::darkGray);
+	painter.setPen(QPen(rgbLite1, 2));
 	painter.setBrush(grad);
-	painter.drawPath(path);
+	painter.drawPath(m_path);
 
 #ifdef CONFIG_DEBUG_0
 	painter.drawText(QFrame::rect(),
@@ -328,4 +240,122 @@ void samplv1widget_filt::wheelEvent ( QWheelEvent *pWheelEvent )
 }
 
 
+// Resize canvas.
+void samplv1widget_filt::resizeEvent ( QResizeEvent *pResizeEvent )
+{
+	QFrame::resizeEvent(pResizeEvent);
+
+	updatePath();
+}
+
+
+// Update the drawing polygon.
+void samplv1widget_filt::updatePath (void)
+{
+	const QRect& rect = QWidget::rect();
+	const int h  = rect.height();
+	const int w  = rect.width();
+
+	const int h2 = h >> 1;
+	const int h4 = h >> 2;
+	const int w4 = w >> 2;
+	const int w8 = w >> 3;
+
+	const int ws = w8 - (m_iSlope == S24DB ? (w8 >> 1) : 0);
+
+	int x = w8 + int(m_fCutoff * float(w - w4));
+	int y = h2 - int(m_fReso   * float(h + h4));
+
+	QPolygon poly(6);
+	QPainterPath path;
+
+	const int iType = (m_iSlope == SFORMANT ? L2F : m_iType);
+	// Low, Notch
+	if (iType == LPF || iType == BRF) {
+		if (iType == BRF) x -= w8;
+		poly.putPoints(0, 6,
+			0, h2,
+			x - w8, h2,
+			x, h2,
+			x, y,
+			x + ws, h,
+			0, h);
+		path.moveTo(poly.at(0));
+		path.lineTo(poly.at(1));
+		path.cubicTo(poly.at(2), poly.at(3), poly.at(4));
+		path.lineTo(poly.at(5));
+		if (iType == BRF) x += w8;
+	}
+	// Band
+	if (iType == BPF) {
+		const int y2 = (y + h4) >> 1;
+		poly.putPoints(0, 6,
+			0, h,
+			x - w8 - ws, h,
+			x - ws, y2,
+			x + ws, y2,
+			x + w8 + ws, h,
+			0, h);
+		path.moveTo(poly.at(0));
+		path.lineTo(poly.at(1));
+		path.cubicTo(poly.at(2), poly.at(3), poly.at(4));
+		path.lineTo(poly.at(5));
+	}
+	// High, Notch
+	if (iType == HPF || iType == BRF) {
+		if (iType == BRF) { x += w8; y = h2; }
+		poly.putPoints(0, 6,
+			x - ws, h,
+			x, y,
+			x, h2,
+			x + w8, h2,
+			w, h2,
+			w, h);
+		path.moveTo(poly.at(0));
+		path.cubicTo(poly.at(1), poly.at(2), poly.at(3));
+		path.lineTo(poly.at(4));
+		path.lineTo(poly.at(5));
+		if (iType == BRF) x -= w8;
+	}
+	// Formant
+	if (iType == L2F) {
+		const int x2 = (x - w4) >> 2;
+		const int y2 = (y - h4) >> 2;
+		poly.putPoints(0, 6,
+			0, h2,
+			x2, h2,
+			x - ws, h2,
+			x, y2,
+			x + ws, h,
+			0, h);
+		path.moveTo(poly.at(0));
+	#if 0
+		path.lineTo(poly.at(1));
+		path.cubicTo(poly.at(2), poly.at(3), poly.at(4));
+	#else
+		const int n3 = 5; // num.formants
+		const int w3 = (x + ws - x2) / n3 - 1;
+		const int w6 = (w3 >> 1);
+		const int h3 = (h4 >> 1);
+		int x3 = x2; int y3 = y2;
+		for (int i = 0; i < n3; ++i) {
+			poly.putPoints(1, 3,
+				x3, h2,
+				x3 + w6, y3,
+				x3 + w3, y3 + h2);
+			path.cubicTo(poly.at(1), poly.at(2), poly.at(3));
+			x3 += w3; y3 += h3;
+		}
+		path.lineTo(poly.at(4));
+	#endif
+		path.lineTo(poly.at(5));
+	}
+
+	// Commit path.
+	m_path = path;
+
+	QFrame::update();
+}
+
+
 // end of samplv1widget_filt.cpp
